
#ifndef _C1_de2_
#define _C1_de2_

#ifdef __cplusplus
extern "C" {
#endif

extern void F2_35(EIF_REFERENCE);
extern void F2_36(EIF_REFERENCE, EIF_POINTER, EIF_REFERENCE);
extern void F2_37(EIF_REFERENCE, EIF_REFERENCE);
extern void F2_38(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F2_39(EIF_REFERENCE);
extern EIF_POINTER F2_40(EIF_REFERENCE);
extern EIF_BOOLEAN F2_41(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit2(void);
extern void F676_3090(EIF_REFERENCE, EIF_INTEGER_32);
extern void F673_3090(EIF_REFERENCE, EIF_INTEGER_32);
extern void F673_3137(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
extern void F676_3137(EIF_REFERENCE, EIF_POINTER, EIF_REFERENCE);
extern void F676_3132(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F673_3098(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F676_3122(EIF_REFERENCE);
extern char *(*R3672[])();

#ifdef __cplusplus
}
#endif

#endif
